<a id="widgets.labeledit.*"></a>

## \*

<a id="widgets.labeledit.LabelEdit"></a>

## LabelEdit Objects

```python
class LabelEdit(QWidget)
```

<a id="widgets.labeledit.LabelEdit.text_changed"></a>

#### text\_changed

<a id="widgets.labeledit.LabelEdit.__init__"></a>

#### \_\_init\_\_

```python
def __init__(text, *args, changed=None, **kwargs)
```

<a id="widgets.labeledit.LabelEdit.text"></a>

#### text

```python
def text()
```

<a id="widgets.labeledit.LabelEdit.setText"></a>

#### setText

```python
def setText(text)
```

<a id="widgets.labeledit.LabelEdit.start_editing"></a>

#### start\_editing

```python
def start_editing()
```

<a id="widgets.labeledit.LabelEdit.mouseDoubleClickEvent"></a>

#### mouseDoubleClickEvent

```python
def mouseDoubleClickEvent(event: QtGui.QMouseEvent) -> None
```

<a id="widgets.labeledit.LabelEdit.accept"></a>

#### accept

```python
def accept()
```

<a id="widgets.labeledit.LabelEdit.dismiss"></a>

#### dismiss

```python
def dismiss()
```

<a id="widgets.labeledit.LabelEdit.eventFilter"></a>

#### eventFilter

```python
def eventFilter(source, event)
```

